@@ -1,5 +1,5 @@
 /*
- * $Id: Evaluator.java,v 1.3 1998/05/23 12:34:48 metlov Exp $
+ * $Id: Evaluator.java,v 1.5 1998/10/28 23:10:37 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -20,7 +20,7 @@ import gnu.jel.generated.TokenMgrError;
 import gnu.jel.debug.Debug;
 
 /**
- * This is the main front ent to JEL.
+ * This is the main front end to JEL.
  * <P>It is intended for compilation of algebraic expressions, involving 
  * functions.
  * <P> Syntax supports variables, which are, in fact, functions with no 
@@ -68,11 +68,29 @@ public class Evaluator {
   public static CompiledExpression compile(String expression, Library lib,
 					   Class resultType) 
        throws CompilationException {
+    return compileBits(expression,lib,resultType).getExpression();
+  };
+
+  /**
+   * Compiles expression, resolving the function names in the library.
+   * <P>This variant of compile allows to store expressions in a 
+   * <TT>java.io.OutputStream</TT> using Java serialization mechanism.
+   * @param expression is the expression to compile. i.e. "sin(666)" .
+   * @param lib Library of functions exported for use in expression.
+   * @param resultType identifies the type result should be converted to. Can
+   *        be null, in this case the result type is not fixed.
+   * @return Instance of the ExpressionBits class, allowing to store and/or
+   * instantiate compiled expression.
+   * @exception gnu.jel.CompilationException if the expression is not
+   *  syntactically or semantically correct.
+   * @see gnu.jel.CompiledExpression#evaluate
+   */
+  public static ExpressionBits compileBits(String expression, Library lib,
+					   Class resultType) 
+       throws CompilationException {
     Optimizer o=fillOptimizer(expression, lib,resultType);
-    if (Debug.enabled)
-      Debug.println(o.toString());
     o.optimize(1);
-    return o.compile();
+    return o.compileBits();
   };
 
   /**
@@ -90,6 +108,24 @@ public class Evaluator {
     return compile(expression, lib, null);
   };
 
+  /**
+   * Compiles expression, resolving the function names in the library.
+   * <P>This variant of compile allows to store expressions in a 
+   * <TT>java.io.OutputStream</TT> using Java serialization mechanism.
+   * @param expression is the expression to compile. i.e. "sin(666)" .
+   * @param lib Library of functions exported for use in expression.
+   * @return Instance of the ExpressionBits class, allowing to store and/or
+   * instantiate compiled expression.
+   * @exception gnu.jel.CompilationException if the expression is not
+   *  syntactically or semantically correct.
+   * @see gnu.jel.CompiledExpression#evaluate
+   */
+  public static ExpressionBits compileBits(String expression, Library lib)
+       throws CompilationException {
+    return compileBits(expression, lib, null);
+  };
+  
+
   // This is for convenient use in the internal optimizer tests
   static Optimizer fillOptimizer(String expression, Library lib, 
 				 Class resultType) 
