@@ -1,5 +1,5 @@
 /*
- * $Id: TestSuite.java,v 1.10 1998/11/07 19:30:41 metlov Exp $
+ * $Id: TestSuite.java,v 1.11 1998/11/22 14:20:33 metlov Exp $
  *
  * This file is part of the Java Expressions Library (JEL).
  *   For more information about JEL visit :
@@ -51,7 +51,12 @@ public class TestSuite {
     
     o.println(); o.println("----- TESTING ERROR REPORTING ------");
     o.println();
-    
+
+    testError("",null,lib,0,o);
+    testError(" ",null,lib,1,o);
+    testError("tru",null,lib,1,o);
+    testError("1=",null,lib,2,o);
+    testError("1=2",null,lib,3,o);
     testError("1.0-+1.0",null,lib,5,o);
     testError("1.0&1.0",null,lib,4,o);
     testError("-",null,lib,1,o);
